@@ -16,6 +16,7 @@
 
 #include "duktape.h"
 #include "c_eventloop.h"
+#include "duk_console.h"
 
 #define  DUKTAPE_EVENTLOOP_DEBUG 0       /* set to 1 to debug with printf */
 
@@ -186,6 +187,8 @@ static void expire_timers(duk_context *ctx) {
 #if defined(DUKTAPE_EVENTLOOP_DEBUG) && DUKTAPE_EVENTLOOP_DEBUG > 0
             duktape_debug("timer callback failed for timer %d: %s\n", (int) t->id, duk_to_string(ctx, -1));
 #endif
+            duk_c_console_log(1, 1, "%s (while running callback id %d)\n",
+                              duk_safe_to_string(ctx, -1), (int) t->id);
         }
         duk_pop(ctx);    /* ignore errors for now -> [ ... stash eventTimers ] */
 
@@ -377,6 +380,8 @@ duk_ret_t eventloop_run(duk_context *ctx, void *udata) {
 #if defined(DUKTAPE_EVENTLOOP_DEBUG) && DUKTAPE_EVENTLOOP_DEBUG > 0
                     duktape_debug("fd callback failed for fd %d: %s\n", (int) pfd->fd, duk_to_string(ctx, -1));
 #endif
+                    duk_c_console_log(1, 1, "%s (while running callback id %d on fd %d)\n",
+                                      duk_safe_to_string(ctx, -1), (int) t->id, (int) pfd->fd);
                 }
                 duk_pop(ctx);
 
